# Information
This package to fetch data from cnbc
## Installation
```bash
pip install cnbcfinance

```
## Get History by interval
* Get data by interval and period
```bash
from cnbcfinance import get_history_df
```
## Get Quote
* Get quote data realtime
```bash
from cnbcfinance import get_quote
```
